@@ -23,8 +23,7 @@ class DatasetClient(ServiceClient):
     HEADER_UPLOAD_OFFSET = "Upload-Offset"
     HEADER_DIGEST = "Digest"
     HEADER_LAST_MODIFIED = "Last-Modified"
-
-    SHA256 = "SHA256"
+    HEADER_CONTENT_LENGTH = "Content-Length"
 
     REQUEST_SIZE_LIMIT = 32 * 1024 * 1024
 
@@ -266,7 +265,7 @@ class DatasetClient(ServiceClient):
     def stream_file(
         self,
         dataset: Union[str, Dataset],
-        file_name: str,
+        file: Union[str, FileInfo],
         offset: int = 0,
         length: int = -1,
         max_retries: int = 5,
@@ -277,7 +276,8 @@ class DatasetClient(ServiceClient):
         Stream download the contents of a single file from a dataset.
 
         :param dataset: The dataset ID, name, or object.
-        :param file_name: The path of the file within the dataset.
+        :param file: The path of the file within the dataset or the corresponding
+            :class:`~beaker.data_model.dataset.FileInfo` object.
         :param offset: Offset to start from, in bytes.
         :param length: Number of bytes to read.
         :param max_retries: Number of times to restart the download when HTTP errors occur.
@@ -293,26 +293,11 @@ class DatasetClient(ServiceClient):
         :raises BeakerError: Any other :class:`~beaker.exceptions.BeakerError` type that can occur.
         :raises HTTPError: Any other HTTP exception that can occur.
         """
-        dataset: Dataset = self.resolve_dataset(dataset)
-        if dataset.storage is None:
-            # Might need to get dataset again if 'storage' hasn't been set yet.
-            dataset = self.get(dataset.id)
-        if dataset.storage is None:
-            raise DatasetReadError(dataset.id)
-        response = self.request(
-            f"datasets/{dataset.storage.id}/files/{file_name}",
-            method="HEAD",
-            token=dataset.storage.token,
-            base_url=dataset.storage.address,
-            exceptions_for_status={404: FileNotFoundError(file_name)},
-        )
-        file_info = FileInfo(
-            path=file_name,
-            digest=response.headers[self.HEADER_DIGEST],
-            updated=datetime.strptime(
-                response.headers[self.HEADER_LAST_MODIFIED], "%a, %d %b %Y %H:%M:%S %Z"
-            ),
-        )
+        dataset: Dataset = self.resolve_dataset(dataset, ensure_storage=True)
+        assert dataset.storage is not None
+
+        file_info = file if isinstance(file, FileInfo) else self.file_info(dataset, file)
+
         from ..progress import get_unsized_dataset_fetch_progress
 
         with get_unsized_dataset_fetch_progress(quiet=quiet) as progress:
@@ -328,6 +313,39 @@ class DatasetClient(ServiceClient):
                 progress.update(task_id, advance=len(bytes_chunk))
                 yield bytes_chunk
 
+    def file_info(self, dataset: Union[str, Dataset], file_name: str) -> FileInfo:
+        """
+        Get the :class:`~beaker.data_model.dataset.FileInfo` for a file in a dataset.
+
+        :param dataset: The dataset ID, name, or object.
+        :param file_name: The path of the file within the dataset.
+
+        :raises DatasetNotFound: If the dataset can't be found.
+        :raises DatasetReadError: If the :data:`~beaker.data_model.dataset.Dataset.storage` hasn't been set.
+        :raises FileNotFoundError: If the file doesn't exist in the dataset.
+        :raises BeakerError: Any other :class:`~beaker.exceptions.BeakerError` type that can occur.
+        :raises HTTPError: Any other HTTP exception that can occur.
+        """
+        dataset: Dataset = self.resolve_dataset(dataset, ensure_storage=True)
+        assert dataset.storage is not None
+        response = self.request(
+            f"datasets/{dataset.storage.id}/files/{file_name}",
+            method="HEAD",
+            token=dataset.storage.token,
+            base_url=dataset.storage.address,
+            exceptions_for_status={404: FileNotFoundError(file_name)},
+        )
+        size_str = response.headers.get(self.HEADER_CONTENT_LENGTH)
+        size = int(size_str) if size_str else None
+        return FileInfo(
+            path=file_name,
+            digest=response.headers[self.HEADER_DIGEST],
+            updated=datetime.strptime(
+                response.headers[self.HEADER_LAST_MODIFIED], "%a, %d %b %Y %H:%M:%S %Z"
+            ),
+            size=size,
+        )
+
     def delete(self, dataset: Union[str, Dataset]):
         """
         Delete a dataset.
@@ -550,7 +568,7 @@ class DatasetClient(ServiceClient):
 
             source_file_wrapper = BufferedReaderWithProgress(source_file, progress, task_id)
             body: Optional[BufferedReaderWithProgress] = source_file_wrapper
-            digest: Optional[bytes] = None
+            digest: Optional[str] = None
 
             if size > self.REQUEST_SIZE_LIMIT:
                 response = self.request(
@@ -579,9 +597,8 @@ class DatasetClient(ServiceClient):
                     )
                     written += len(chunk)
 
-                    encoded_digest = response.headers.get(self.HEADER_DIGEST)
-                    if encoded_digest:
-                        digest = self._decode_digest(encoded_digest)
+                    digest = response.headers.get(self.HEADER_DIGEST)
+                    if digest:
                         break
 
                 if written != size:
@@ -595,7 +612,7 @@ class DatasetClient(ServiceClient):
                 data=body,
                 token=dataset.storage.token,
                 base_url=dataset.storage.address,
-                headers=None if not digest else {self.HEADER_DIGEST: self._encode_digest(digest)},
+                headers=None if not digest else {self.HEADER_DIGEST: digest},
                 stream=body is not None,
                 exceptions_for_status={
                     403: DatasetWriteError(dataset.id),
@@ -605,20 +622,6 @@ class DatasetClient(ServiceClient):
 
             return source_file_wrapper.total_read
 
-    def _encode_digest(self, digest: bytes) -> str:
-        import base64
-
-        return f"{self.SHA256} {base64.standard_b64encode(digest).decode()}"
-
-    def _decode_digest(self, encoded_digest: str) -> bytes:
-        import base64
-
-        if self.SHA256 in encoded_digest:
-            _, encoded = encoded_digest.split(" ", 2)
-        else:
-            encoded = encoded_digest
-        return base64.standard_b64decode(encoded)
-
     def _iter_files(self, storage: DatasetStorage) -> Generator[FileInfo, None, None]:
         from collections import deque
 
@@ -690,11 +693,11 @@ class DatasetClient(ServiceClient):
 
         # Validate digest.
         if sha256_hash is not None:
-            digest = sha256_hash.digest()
-            if self._decode_digest(file_info.digest) != digest:
+            digest = Digest(sha256_hash.digest())
+            if file_info.digest != digest:
                 raise ChecksumFailedError(
                     f"Checksum for '{file_info.path}' failed. "
-                    f"Expected '{file_info.digest}', got '{self._encode_digest(digest)}'."
+                    f"Expected '{file_info.digest}', got '{digest}'."
                 )
 
     def _download_file(
